@@ -16,7 +16,7 @@ sub add {
 
 sub addfile {
   my ($self, $file) = @_;
-  
+
   my $handle;
   if (ref(\$file) eq 'SCALAR') {
     #filename
@@ -26,19 +26,27 @@ sub addfile {
   else {
     #handle
     $handle = $file
-  }  
+  }
   die "FATAL: invalid handle" unless defined $handle;
-  
+
   my $n;
   my $buf = "";
   while (($n = read($handle, $buf, 32*1024))) {
     $self->_add_single($buf)
   }
   die "FATAL: read failed: $!" unless defined $n;
-  
+
   return $self;
 }
 
 sub CLONE_SKIP { 1 } # prevent cloning
 
-1;
\ No newline at end of file
+1;
+
+__END__
+ 
+=head1 NAME
+ 
+Crypt::mode - [internal only]
+ 
+=cut
\ No newline at end of file
